"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ALGOImplementation = void 0;
const msgpack = __importStar(require("algo-msgpack-with-bigint"));
const axios_1 = __importDefault(require("axios"));
const __1 = require("..");
const axios_rate_limit_1 = __importDefault(require("../axios-rate-limiter/axios-rate-limit"));
const AlgoIndexerBlock_1 = require("../base-objects/blocks/AlgoIndexerBlock");
const StatusBase_1 = require("../base-objects/StatusBase");
const AlgoIndexerTransaction_1 = require("../base-objects/transactions/AlgoIndexerTransaction");
const types_1 = require("../types");
const algoUtils_1 = require("../utils/algoUtils");
const errors_1 = require("../utils/errors");
const managed_1 = require("../utils/managed");
const utils_1 = require("../utils/utils");
const DEFAULT_TIMEOUT = 60000;
const DEFAULT_RATE_LIMIT_OPTIONS = {
    maxRPS: 5,
};
function algoResponseValidator(responseCode) {
    // allow any response, process them later in mcc
    return responseCode >= 200 && responseCode < 600;
}
let ALGOImplementation = class ALGOImplementation {
    constructor(createConfig) {
        this.createConfig = createConfig;
        const algodClient = axios_1.default.create({
            baseURL: createConfig.algod.url,
            timeout: DEFAULT_TIMEOUT,
            headers: {
                "Content-Type": "application/json",
                "X-Algo-API-Token": createConfig.algod.token,
                "x-api-key": createConfig.algod.token,
            },
            validateStatus: algoResponseValidator,
        });
        this.algodClient = (0, axios_rate_limit_1.default)(algodClient, Object.assign(Object.assign({}, DEFAULT_RATE_LIMIT_OPTIONS), createConfig.rateLimitOptions));
        if (createConfig.indexer) {
            const indexerClient = axios_1.default.create({
                baseURL: createConfig.indexer.url,
                timeout: DEFAULT_TIMEOUT,
                headers: {
                    "Content-Type": "application/json",
                    "X-Algo-API-Token": createConfig.indexer.token,
                    "x-api-key": createConfig.indexer.token,
                },
                validateStatus: algoResponseValidator,
            });
            this.indexerClient = (0, axios_rate_limit_1.default)(indexerClient, Object.assign(Object.assign({}, DEFAULT_RATE_LIMIT_OPTIONS), createConfig.rateLimitOptions));
        }
        if (!createConfig.inRegTest) {
            this.inRegTest = false;
        }
        else {
            this.inRegTest = createConfig.inRegTest;
        }
        this.chainType = types_1.ChainType.ALGO;
    }
    /**
     * Return node status object for Algo node
     */
    async getNodeStatus() {
        let res = await this.algodClient.get("health");
        (0, algoUtils_1.algo_ensure_data)(res);
        let ver = await this.algodClient.get("versions");
        (0, algoUtils_1.algo_ensure_data)(ver);
        let status = await this.algodClient.get("/v2/status");
        (0, algoUtils_1.algo_ensure_data)(status);
        status = (0, utils_1.toCamelCase)(status.data);
        const statusData = {
            health: res.status,
            status: status,
            versions: (0, utils_1.toCamelCase)(ver.data),
        };
        return new StatusBase_1.AlgoNodeStatus(statusData);
    }
    async getBottomBlockHeight() {
        let bottomBlockHeight = await this.getBlockHeight();
        // check -1.000 -10.000 and -100.000 blocs
        for (let checkRound = 0; checkRound < 3; checkRound++) {
            bottomBlockHeight -= Math.pow(10, 3 + checkRound);
            let blc = await this.algodClient.get(`/v2/blocks/${bottomBlockHeight}`);
            if (blc.status !== 200) {
                // we didn't get block
                for (let i = 0; i < 10; i++) {
                    bottomBlockHeight += Math.pow(10, 2 + checkRound);
                    blc = await this.algodClient.get(`/v2/blocks/${bottomBlockHeight}`);
                    if (blc.status === 200) {
                        break;
                    }
                }
                // If we ever come here we are not healthy
            }
        }
        return bottomBlockHeight;
    }
    ///////////////////////////////////////////////////////////////////////////////////////
    // Block methods //////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////////////////
    async getBlock(round) {
        if (round === undefined) {
            const status = await this.getStatus();
            round = status.lastRound;
        }
        let res = await this.algodClient.get(`/v2/blocks/${round}?format=msgpack`, {
            responseType: "arraybuffer",
            headres: { "Content-Type": "application/msgpack" },
        });
        if ((0, algoUtils_1.algo_check_expect_block_out_of_range)(res)) {
            throw new errors_1.mccError(errors_1.mccErrorCode.InvalidBlock);
        }
        (0, algoUtils_1.algo_ensure_data)(res);
        const decoded = (0, algoUtils_1.mpDecode)(res.data);
        return new __1.AlgoBlock(decoded);
    }
    async getBlockHeight(round) {
        const blockData = await this.getBlockHeader(round);
        return blockData.block.rnd;
    }
    async getBlockProof(round) {
        return await this.getBlockHeaderCert(round);
    }
    ///////////////////////////////////////////////////////////////////////////////////////
    // Transaction methods ////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////////////////
    /**
     * get Transaction cannot be called on algorand's algod client, use getIndexerTransaction instead or get transactions from block
     * @param txid
     */
    async getTransaction(txid) {
        throw new errors_1.mccError(errors_1.mccErrorCode.InvalidMethodCall);
    }
    async listTransactions(options) {
        if (!this.createConfig.indexer) {
            // No indexer
            return null;
        }
        let snakeObject = {};
        if (options !== undefined) {
            snakeObject = (0, utils_1.toSnakeCase)(options);
        }
        let res = await this.indexerClient.get(`/v2/transactions`, {
            params: snakeObject,
        });
        (0, algoUtils_1.algo_ensure_data)(res);
        let camelList = {
            currentRound: res.data["current-round"],
            nextToken: res.data["next-token"],
            transactions: [],
        };
        for (let key of Object.keys(res.data.transactions)) {
            camelList.transactions.push((0, utils_1.toCamelCase)(res.data.transactions[key]));
        }
        return camelList;
    }
    ///////////////////////////////////////////////////////////////////////////////////////
    // Build-in Assets (ASAs) methods /////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////////////////
    async getAssetInfo(assetId) {
        let res = await this.algodClient.get(`/v2/assets/${assetId}`);
        (0, algoUtils_1.algo_ensure_data)(res);
        return res.data;
    }
    ///////////////////////////////////////////////////////////////////////////////////////
    // Client helper (private) methods ////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////////////////
    async getStatus() {
        let res = await this.algodClient.get("/v2/status");
        (0, algoUtils_1.algo_ensure_data)(res);
        return (0, utils_1.toCamelCase)(res.data);
    }
    async getBlockHeaderCert(round) {
        let res = await this.algodClient.get(`/v2/blocks/${round}?format=msgpack`, {
            responseType: "arraybuffer",
            headres: { "Content-Type": "application/msgpack" },
        });
        (0, algoUtils_1.algo_ensure_data)(res);
        const decoded = msgpack.decode(res.data);
        return decoded.cert;
    }
    async getBlockHeader(round) {
        if (round === undefined) {
            const status = await this.getStatus();
            round = status.lastRound;
        }
        let resorig = await this.algodClient.get(`/v2/blocks/${round}`);
        (0, algoUtils_1.algo_ensure_data)(resorig);
        let responseData = (0, utils_1.toCamelCase)(resorig.data);
        responseData.type = "IAlgoGetBlockHeaderRes";
        return responseData;
    }
    ///////////////////////////////////////////////////////////////////////////////////////
    // Indexer specific methods  //////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////////////////
    /**
     * Get trasnaction from node by its id
     * @param txid base32 encoded txid || standardized txid (prefixed or unprefixed)
     * @returns
     */
    async getIndexerTransaction(txid) {
        if ((0, utils_1.isPrefixed0x)(txid)) {
            txid = (0, utils_1.unPrefix0x)(txid);
        }
        let res = await this.indexerClient.get(`/v2/transactions/${txid}`);
        if ((0, algoUtils_1.algo_check_expect_empty)(res)) {
            throw new errors_1.mccError(errors_1.mccErrorCode.InvalidBlock);
        }
        (0, algoUtils_1.algo_ensure_data)(res);
        return new AlgoIndexerTransaction_1.AlgoIndexerTransaction((0, utils_1.toCamelCase)(res.data));
    }
    async getIndexerBlock(round) {
        if (!this.createConfig.indexer) {
            // No indexer
            throw new errors_1.mccError(errors_1.mccErrorCode.InvalidMethodCall);
        }
        if (round === undefined) {
            const status = await this.getStatus();
            round = status.lastRound - 1;
        }
        let res = await this.indexerClient.get(`/v2/blocks/${round}`);
        if ((0, algoUtils_1.algo_check_expect_block_out_of_range)(res)) {
            throw new errors_1.mccError(errors_1.mccErrorCode.InvalidBlock);
        }
        (0, algoUtils_1.algo_ensure_data)(res);
        const cert = await this.getBlockHeaderCert(round);
        let camelBlockRes = (0, utils_1.toCamelCase)(res.data);
        camelBlockRes.transactions = [];
        for (let key of Object.keys(res.data.transactions)) {
            camelBlockRes.transactions.push((0, utils_1.toCamelCase)(res.data.transactions[key]));
        }
        camelBlockRes.cert = (0, algoUtils_1.certToInCert)(cert);
        return new AlgoIndexerBlock_1.AlgoIndexerBlock(camelBlockRes);
    }
    async getIndexerAssetInfo(assetIndex) {
        let res = await this.indexerClient.get(`/v2/assets/${assetIndex}`);
        if ((0, algoUtils_1.algo_check_expect_empty)(res)) {
            throw new errors_1.mccError(errors_1.mccErrorCode.InvalidResponse);
        }
        (0, algoUtils_1.algo_ensure_data)(res);
        return res.data.asset;
    }
};
ALGOImplementation = __decorate([
    (0, managed_1.Managed)()
], ALGOImplementation);
exports.ALGOImplementation = ALGOImplementation;
//# sourceMappingURL=AlgoRpcImplementation.js.map