import { RateLimitOptions } from "../types";
import { IIGetBlockRes, IIGetTransactionRes, MccLoggingOptions, RPCInterface } from "./genericMccTypes";
export declare class UtxoMccCreate {
    url: string;
    username: string;
    password: string;
    inRegTest?: boolean;
    rateLimitOptions?: RateLimitOptions | undefined;
    loggingOptions?: MccLoggingOptions | undefined;
}
export interface IIUtxoVin {
    txid: string;
    vout: number;
    sequence?: number;
}
export interface IIUtxoVout {
    address: string;
    amount: number;
}
export interface IUtxoScriptPubKey {
    asm: string;
    hex: string;
    reqSigs?: number;
    type: string;
    addresses?: string[];
    address?: string;
}
export interface UtxoVout {
    value: number;
    n: number;
    scriptPubKey: IUtxoScriptPubKey;
}
export interface IUtxoScriptSig {
    asm: string;
    hex: string;
}
export interface IUtxoWalletRes {
    name: string;
    warning: string;
}
export interface getAddressByLabelResponse {
    address: string;
    purpose: string;
}
export interface IUtxoTransactionListRes {
    txid: string;
    vout: number;
    address: string;
    label: string;
    scriptPubKey: string;
    amount: number;
    confirmations: number;
    spendable: boolean;
    solvable: boolean;
    desc: string;
    safe: boolean;
}
export interface IUtxoGetBlockHeaderRes {
    hash: string;
    confirmations: number;
    height: number;
    version: number;
    versionHex: string;
    merkleroot: string;
    time: number;
    mediantime: number;
    nonce: number;
    bits: string;
    difficulty: number;
    chainwork: string;
    previousblockhash: string;
    nextblockhash: string;
}
export interface IUtxoGetBlockRes extends IUtxoGetBlockHeaderRes, IIGetBlockRes {
    size: number;
    strippedsize: number;
    weight: number;
    tx: IUtxoInBlockTransaction[];
    nTx: number;
}
/**
 * Vin interface from transaction details requests
 */
export interface IUtxoVinTransaction {
    coinbase?: string;
    sequence: number;
    txid?: string;
    vout?: number;
    scriptSig?: IUtxoScriptSig;
    txinwitness?: string[];
}
export interface IUtxoCoinbase {
    coinbase?: string;
}
export interface IUtxoVoutTransaction {
    value: number;
    n: number;
    scriptPubKey: IUtxoScriptPubKey;
}
export interface IUtxoInBlockTransaction extends IIGetTransactionRes {
    txid: string;
    hash: string;
    version: number;
    size: number;
    vsize: number;
    weight: number;
    locktime: number;
    vin: IUtxoVinTransaction[];
    vout: IUtxoVoutTransaction[];
    hex: string;
}
export interface IUtxoGetTransactionRes extends IIGetTransactionRes {
    txid: string;
    hash: string;
    version: number;
    size: number;
    vsize: number;
    weight: number;
    locktime: number;
    vin: IUtxoVinTransaction[];
    vout: IUtxoVoutTransaction[];
    hex: string;
    blockhash: string;
    confirmations: number;
    time: number;
    blocktime: number;
}
export interface IUtxoGetAlternativeBlocksOptions {
    height_gte?: number;
    all_blocks?: boolean;
}
export declare type IUtxoGetAlternativeBlocksRes = IUtxoChainTip[];
export interface IUtxoChainTip {
    height: number;
    hash: string;
    branchlen: number;
    status: "active" | "valid-fork" | "valid-headers" | "headers-only" | "invalid";
    all_block_hashes?: string[];
}
export interface IUtxoVinVoutsMapper {
    index: number;
    vinvout: IUtxoVoutTransaction | undefined;
}
export interface IUtxoTransactionAdditionalData {
    vinouts?: (IUtxoVinVoutsMapper | undefined)[];
}
interface INetworks {
    name: string;
    limited: boolean;
    reachable: boolean;
    proxy: string;
    proxy_randomize_credentials: boolean;
}
interface ILocalAddresses {
    address: string;
    port: number;
    score: number;
}
export interface IUtxoGetNetworkInfoRes {
    version: number;
    subversion: string;
    protocolversion: number;
    localservices: string;
    localservicesnames: string[];
    localrelay: boolean;
    timeoffset: number;
    connections: number;
    connections_in: number;
    connections_out: number;
    networkactive: boolean;
    networks: INetworks[];
    relayfee: number;
    incrementalfee: number;
    localaddresses: ILocalAddresses[];
    warnings: string;
}
export interface IUtxoGetBlockchainInfoRes {
    chain: "main" | "test" | "regtest";
    blocks: number;
    headers: number;
    bestblockhash: string;
    difficulty: number;
    mediantime: number;
    verificationprogress: number;
    initialblockdownload: boolean;
    chainwork: string;
    size_on_disk: number;
    pruned: boolean;
    pruneheight: number;
    automatic_pruning: boolean;
    prune_target_size: number;
    softforks: any;
    warnings: string;
}
export declare type IUtxoNodeStatus = IUtxoGetBlockchainInfoRes & IUtxoGetNetworkInfoRes;
export interface UtxoRpcInterface extends RPCInterface {
    getBlockHeader(blockHash: string): any;
    createWallet(walletLabel: string): any;
    loadWallet(walletLabel: string): any;
    createAddress(walletLabel: string, addressLabel?: string, address_type?: string): any;
    listAllWallets(): any;
    listAllAddressesByLabel(walletLabel: string, addressLabel: string): Promise<any[]>;
    listUnspentTransactions(walletLabel: string, min: number, max: number): any;
    getPrivateKey(walletLabel: string, address: string): any;
}
export {};
//# sourceMappingURL=utxoTypes.d.ts.map