"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.retry = void 0;
const __1 = require("..");
const utils_1 = require("./utils");
let TIMEOUT_STEP_MULTIPLY = 1.2;
let BACKOFF_TIME_STEP_MULTIPLY = 1.2;
const retrySleepResult = "wVgdz8YJgsUud6CPtKYH8tw4mHdLHLbgrEGsGqdWetPDKWAW5hbZ5LMz";
async function retrySleepMs(ms) {
    await (0, utils_1.sleepMs)(ms);
    return retrySleepResult;
}
async function retry(label, funct, timeoutTime = 5000, numRetries = 5, backOddTimeout = 1000, exceptionCallback = __1.defaultExceptionCallback, warningCallback = __1.defaultWarningCallback, failure = (label) => { }) {
    try {
        let result = await Promise.race([funct(), retrySleepMs(timeoutTime)]);
        if (result !== retrySleepResult)
            return result;
        // timeout section
        if (numRetries > 0) {
            warningCallback(`retry ^R${label}^^ ${numRetries}`);
            await (0, utils_1.sleepMs)(backOddTimeout / 2 + (0, utils_1.getSimpleRandom)(backOddTimeout / 2));
            return retry(label, funct, timeoutTime * TIMEOUT_STEP_MULTIPLY, numRetries - 1, backOddTimeout * BACKOFF_TIME_STEP_MULTIPLY, exceptionCallback, warningCallback, failure);
        }
        else {
            warningCallback(`retry ^R${label}^^ failed`);
            // failure callback
            failure(label);
            //  return null; // TODO this should probably raise an error
            throw (0, __1.MccError)(`retry ^R${label}^^ failed`);
        }
    }
    catch (error) {
        // exception section
        if (numRetries > 0) {
            exceptionCallback(error, `retry ^R${label}^^ exception (retry ${numRetries})`);
            await (0, utils_1.sleepMs)(backOddTimeout / 2 + (0, utils_1.getSimpleRandom)(backOddTimeout / 2));
            return retry(label, funct, timeoutTime * TIMEOUT_STEP_MULTIPLY, numRetries - 1, backOddTimeout * BACKOFF_TIME_STEP_MULTIPLY, exceptionCallback, warningCallback, failure);
        }
        else {
            exceptionCallback(error, `retry ^R${label}^^ exception (retry failed)`);
            // failure callback
            failure(label);
            //  return null;
            throw (0, __1.MccError)(error);
        }
    }
}
exports.retry = retry;
//# sourceMappingURL=retry.js.map