"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fillWithDefault = exports.defaultMccLoggingObject = exports.defaultExceptionCallback = exports.defaultWarningCallback = exports.defaultLoggingCallback = exports.mccJsonStringify = exports.isValidBytes32Hex = exports.toSnakeCase = exports.camelToSnakeCase = exports.toCamelCase = exports.toNumber = exports.toBN = exports.toHex = exports.isPrefixed0x = exports.prefix0x = exports.unPrefix0x = exports.sleepMs = exports.getSimpleRandom = exports.MccError = exports.ZERO_BYTES_32 = void 0;
const web3_1 = __importDefault(require("web3"));
const camelCase = require("camelcase");
const safeStringify = require('fast-safe-stringify');
exports.ZERO_BYTES_32 = "0x0000000000000000000000000000000000000000000000000000000000000000";
function MccError(error) {
    try {
        const message = mccJsonStringify(error);
        return new Error(message);
    }
    catch (thisError) {
        return new Error(`MCC stringify error ${thisError}`);
    }
}
exports.MccError = MccError;
function getSimpleRandom(maxnum) {
    return Math.floor(Math.random() * maxnum);
}
exports.getSimpleRandom = getSimpleRandom;
async function sleepMs(ms) {
    await new Promise((resolve) => setTimeout(() => resolve(), ms));
}
exports.sleepMs = sleepMs;
function unPrefix0x(tx) {
    if (!tx) {
        return "0x0";
    }
    return tx.startsWith("0x") ? tx.slice(2) : tx;
}
exports.unPrefix0x = unPrefix0x;
function prefix0x(tx) {
    if (!tx) {
        return "0x0";
    }
    return tx.startsWith("0x") ? tx : "0x" + tx;
}
exports.prefix0x = prefix0x;
function isPrefixed0x(tx) {
    if (!tx) {
        return false;
    }
    return tx.startsWith("0x") ? true : false;
}
exports.isPrefixed0x = isPrefixed0x;
function toHex(x) {
    return web3_1.default.utils.toHex(x);
}
exports.toHex = toHex;
function toBN(x, toZeroIfFails = false) {
    if (x && x.constructor && x.constructor.name === "BN")
        return x;
    try {
        return web3_1.default.utils.toBN(x);
    }
    catch (e) {
        if (toZeroIfFails) {
            return web3_1.default.utils.toBN(0);
        }
        throw MccError(e);
    }
}
exports.toBN = toBN;
function toNumber(x) {
    if (x === undefined || x === null)
        return undefined;
    if (x && x.constructor && x.constructor.name === "BN")
        return x.toNumber();
    return x;
}
exports.toNumber = toNumber;
function toCamelCase(obj) {
    let camelObject = {};
    for (let prop in obj) {
        if (typeof obj[prop] == "object") {
            camelObject[camelCase(prop)] = toCamelCase(obj[prop]);
        }
        else {
            camelObject[camelCase(prop)] = obj[prop];
        }
    }
    return camelObject;
}
exports.toCamelCase = toCamelCase;
function camelToSnakeCase(str, splitWith = "-") {
    return str.replace(/[A-Z]/g, (letter) => `${splitWith}${letter.toLowerCase()}`);
}
exports.camelToSnakeCase = camelToSnakeCase;
function toSnakeCase(obj, splitWith = "-") {
    let camelObject = {};
    for (let prop in obj) {
        if (typeof obj[prop] == "object") {
            camelObject[camelToSnakeCase(camelCase(prop), splitWith)] = toSnakeCase(obj[prop], splitWith);
        }
        else {
            camelObject[camelToSnakeCase(camelCase(prop), splitWith)] = obj[prop];
        }
    }
    return camelObject;
}
exports.toSnakeCase = toSnakeCase;
function isValidBytes32Hex(address) {
    return /^0x[0-9a-fA-F]{64}$/i.test(address);
}
exports.isValidBytes32Hex = isValidBytes32Hex;
////////////////////////////////////////////////////////////////////////////////////////////////////
////////// json stringify wrapper //////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////
function mccJsonStringify(toStringify) {
    const options = {
        depthLimit: 2,
        edgesLimit: 3
    };
    return safeStringify(toStringify, null, 2, options);
}
exports.mccJsonStringify = mccJsonStringify;
////////////////////////////////////////////////////////////////////////////////////////////////////
////////// Default logging and exception callbacks /////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////
function defaultLoggingCallback(message) {
    console.log(message);
}
exports.defaultLoggingCallback = defaultLoggingCallback;
function defaultWarningCallback(message) {
    console.log(message);
}
exports.defaultWarningCallback = defaultWarningCallback;
function defaultExceptionCallback(error, message) {
    console.log(message);
    console.error(error);
    if (error.stack) {
        console.error(error.stack);
    }
}
exports.defaultExceptionCallback = defaultExceptionCallback;
function defaultMccLoggingObject() {
    return {
        mode: "develop",
        loggingCallback: defaultLoggingCallback,
        warningCallback: defaultWarningCallback,
        exceptionCallback: defaultExceptionCallback,
    };
}
exports.defaultMccLoggingObject = defaultMccLoggingObject;
function fillWithDefault(partialMccLogging) {
    return {
        mode: partialMccLogging.mode ? partialMccLogging.mode : "develop",
        loggingCallback: partialMccLogging.loggingCallback ? partialMccLogging.loggingCallback : defaultLoggingCallback,
        warningCallback: partialMccLogging.warningCallback ? partialMccLogging.warningCallback : defaultWarningCallback,
        exceptionCallback: partialMccLogging.exceptionCallback ? partialMccLogging.exceptionCallback : defaultExceptionCallback,
    };
}
exports.fillWithDefault = fillWithDefault;
//# sourceMappingURL=utils.js.map