"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const algoCreateConfig = {
    algod: {
        url: process.env.ALGO_ALGOD_URL || "",
        token: process.env.ALGO_ALGOD_TOKEN || "",
    },
    indexer: {
        url: process.env.ALGO_INDEXER_URL || "",
        token: process.env.ALGO_INDEXER_TOKEN || "",
    },
};
describe(`Algo block from algod and indexer compare`, async () => {
    const checkBlocks = [21374440, 21400000, 21500000, 21600000, 21700000, 21797543, 21800000, 21900000, 21931716];
    let MccClient;
    before(async function () {
        MccClient = new src_1.MCC.ALGO(algoCreateConfig);
    });
    for (let hei of checkBlocks) {
        describe(`Compare block from indexer and algod ${hei}`, function () {
            let block;
            let IBlock;
            before(async function () {
                IBlock = await MccClient.getIndexerBlock(hei);
                block = await MccClient.getBlock(hei);
            });
            it("Should compare block number ", async function () {
                (0, chai_1.expect)(block.number).to.eq(IBlock.number);
            });
            it("Should compare block hash ", async function () {
                (0, chai_1.expect)(block.blockHash).to.eq(IBlock.blockHash);
            });
            it("Should compare block standard hash ", async function () {
                (0, chai_1.expect)(block.stdBlockHash).to.eq(IBlock.stdBlockHash);
            });
            it("Should compare block timestamp ", async function () {
                (0, chai_1.expect)(block.unixTimestamp).to.eq(IBlock.unixTimestamp);
            });
            it("Should compare transaction ids ", async function () {
                let diffs = 0;
                let trans1 = block.transactionIds;
                const trans2 = IBlock.transactionIds;
                (0, chai_1.expect)(trans1.length).to.eq(trans2.length);
                let allSame = true;
                for (let i = 0; i < trans2.length; i++) {
                    const found = trans1.find((elem) => trans2[i] === elem);
                    if (found) {
                        trans1 = trans1.filter((elem) => !(found === elem));
                    }
                    else {
                        // transaction was not found
                        diffs += 1;
                        const indexTr = await MccClient.getIndexerTransaction(trans2[i]);
                        allSame = false;
                    }
                }
                if (!allSame) {
                    console.log("diffs: ", diffs);
                }
                (0, chai_1.expect)(allSame).to.eq(true);
            });
            it("Should compare transaction standard ids ", async function () {
                let diffs = 0;
                const trans1 = block.stdTransactionIds;
                const trans2 = IBlock.stdTransactionIds;
                (0, chai_1.expect)(trans1.length).to.eq(trans2.length);
                let allSame = true;
                for (let i = 0; i < trans2.length; i++) {
                    // find all transaction ids in indexer block, and if not print them out
                    const found = trans1.find((elem) => trans2[i] === elem);
                    if (found) {
                    }
                    else {
                        // transaction was not found
                        diffs += 1;
                        allSame = false;
                    }
                }
                if (!allSame) {
                    console.log("diffs: ", diffs);
                }
                (0, chai_1.expect)(allSame).to.eq(true);
            });
            it("Should compare transaction count ", async function () {
                (0, chai_1.expect)(block.transactionCount).to.eq(IBlock.transactionCount);
            });
        });
    }
});
//# sourceMappingURL=blockCompare.test.js.map