"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const algoCreateConfig = {
    algod: {
        url: process.env.ALGO_ALGOD_URL || "",
        token: process.env.ALGO_ALGOD_TOKEN || "",
    },
};
describe("Algo Node Status tests (LIFE: expect healthy) ", function () {
    let MccClient;
    let status;
    before(async function () {
        MccClient = new src_1.MCC.ALGO(algoCreateConfig);
        const tStatus = await MccClient.getNodeStatus();
        if (tStatus) {
            status = tStatus;
        }
    });
    it("Should get status version ", async function () {
        const version = status.version.split("_");
        (0, chai_1.expect)(version[0]).to.be.eq("3");
    });
    it("Should get status state ", async function () {
        // TODO
        (0, chai_1.expect)(status.state).to.eq("TODO");
    });
    it("Should get status isHealthy ", async function () {
        (0, chai_1.expect)(status.isHealthy).to.eq(true);
    });
    it("Should get status isSynced ", async function () {
        (0, chai_1.expect)(status.isSynced).to.eq(true);
    });
});
describe("Algo block height", function () {
    let MccClient;
    before(async function () {
        MccClient = new src_1.MCC.ALGO(algoCreateConfig);
    });
    it("Should get bottom block height ", async function () {
        const bottom = await MccClient.getBottomBlockHeight();
        (0, chai_1.expect)(bottom).to.greaterThan(19000000);
    });
    it("Should get block height ", async function () {
        const h = await MccClient.getBlockHeight(21908076);
        (0, chai_1.expect)(h).to.eq(21908076);
    });
    it("Should get block height 2 ", async function () {
        const h = await MccClient.getBlockHeight();
        (0, chai_1.expect)(h).to.greaterThan(21908076);
    });
    it("Should get block proof ", async function () {
        const c = await MccClient.getBlockProof(21908076);
        (0, chai_1.expect)(c.rnd).to.eq(21908076);
    });
});
//# sourceMappingURL=status.test.js.map